==> xwiki-rendering-wikimodel-6.2.7-sources.jar: org/xwiki/rendering/wikimodel/xhtml/handler/TableTagHandler.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.wikimodel.xhtml.handler;

import org.xwiki.rendering.wikimodel.xhtml.impl.XhtmlHandler;

/**
 * @version $Id: b1e08f37e6048c6b59717241b3024618f41f1985 $
 * @since 4.0M1
 */
public class TableTagHandler extends TagHandler
{
    public TableTagHandler()
    {
        super(false, true, false);
    }

    @Override
    public boolean isBlockHandler(XhtmlHandler.TagStack.TagContext context)
    {
        return true;
    }

    @Override
    protected void begin(XhtmlHandler.TagStack.TagContext context)
    {
        sendEmptyLines(context);
        context.getScannerContext().beginTable(context.getParams());
    }

    @Override
    protected void end(XhtmlHandler.TagStack.TagContext context)
    {
        context.getScannerContext().endTable();
    }
}

==> xwiki-rendering-wikimodel-8.4.1-sources.jar: org/xwiki/rendering/wikimodel/xhtml/handler/TableTagHandler.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.wikimodel.xhtml.handler;

import org.xwiki.rendering.wikimodel.xhtml.impl.TagContext;

/**
 * @version $Id: 9bd676fd2c4c6bb7ad4338b6e2d6464e111a8269 $
 * @since 4.0M1
 */
public class TableTagHandler extends TagHandler
{
    public TableTagHandler()
    {
        super(false);
    }

    @Override
    public boolean isBlockHandler(TagContext context)
    {
        return true;
    }

    @Override
    protected void begin(TagContext context)
    {
        sendEmptyLines(context);
        context.getScannerContext().beginTable(context.getParams());
    }

    @Override
    protected void end(TagContext context)
    {
        context.getScannerContext().endTable();
    }
}
